/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: UploadItemIterator.cpp 2084 2006-11-25 17:00:47Z svn $
 *****************************************************************************/

#include "Environment.h"

#include <algorithm>

#include "apr.h"

#include "UploadItemIterator.h"
#include "UploadItemList.h"
#include "SourceInfo.h"

SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2084 2006-11-25 17:00:47Z svn $");

/******************************************************************************
 * public メソッド
 *****************************************************************************/
UploadItemIterator::UploadItemIterator(apr_pool_t *pool,
                                       UploadItemList *item_list,
                                       apr_size_t start_index,
                                       apr_size_t end_index)
  : curr_index_(0)
{
    validate_index(item_list, &start_index, &end_index);
    size_= end_index - start_index;

    APR_PALLOC(header_list_, UploadItem::header_t *, pool,
               sizeof(UploadItem::header_t)*(end_index-start_index));
    memcpy(header_list_, item_list->get_by_index(start_index),
           sizeof(UploadItem::header_t)*size_);
}

UploadItem *UploadItemIterator::get() const throw()
{
    return AS_UITEM(header_list_ + curr_index_);
}

bool UploadItemIterator::next() throw()
{
    return (++curr_index_ < size_);
}

void UploadItemIterator::reset() throw()
{
    curr_index_ = 0;
}


/******************************************************************************
 * private メソッド
 *****************************************************************************/
void UploadItemIterator::validate_index(UploadItemList *item_list,
                                        apr_size_t *start_index,
                                        apr_size_t *end_index)
{
#ifdef DEBUG
    if (*start_index >= *end_index) {
        THROW(MESSAGE_BUG_FOUND);
    }
#endif

    if (*end_index > item_list->size()) {
        *end_index = item_list->size();
    }
}

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
